@@ -25,7 +25,10 @@ getCountryName <- function(lon, lat, dataset='SimpleCountries', countryCodes=NUL
   if (!exists(dataset)) {
     stop('Missing database. Please loadSpatialData("',dataset,'")',call.=FALSE)
   }
-  
+  # check if longitude and latitude falls in the right range
+  if ( min(lon)< -180 || max(lon) > 180 || min(lat) < -90 || max(lat) > 90 ) {
+    stop('Longitude or latitude is not specified in the correct range -180:180, -90:90',call.=FALSE)
+  }  
   SPDF <- get(dataset)
   
   # Subset by country before searching
@@ -41,15 +44,6 @@ getCountryName <- function(lon, lat, dataset='SimpleCountries', countryCodes=NUL
     
     countryName <- locationsDF$countryName
     
-    # Sanity check -- missing countryName implies location over water  
-    badMask <- is.na(countryName)
-    if (sum(badMask) > 0) {
-      if(is.null(countryCodes)) {
-        warning(paste(sum(badMask),"locations appear to be over international waters and no country can be assigned"))
-      } else {
-        warning(paste(sum(badMask),"locations appear to be either over international waters or not in given countryCodes and no country can be assigned"))
-      }
-    }  
     
     return(countryName)
     
