@@ -29,7 +29,10 @@ getState <- function(lon, lat, dataset='NaturalEarthAdm1', countryCodes=NULL, al
   if (!exists(dataset)) {
     stop('Missing database. Please loadSpatialData("',dataset,'")',call.=FALSE)
   }
-  
+  # check if longitude and latitude falls in the right range
+  if ( min(lon)< -180 || max(lon) > 180 || min(lat) < -90 || max(lat) > 90 ) {
+    stop('Longitude or latitude is not specified in the correct range -180:180, -90:90',call.=FALSE)
+  }  
   SPDF <- get(dataset)
   
   # Subset by country before searching
@@ -45,16 +48,7 @@ getState <- function(lon, lat, dataset='NaturalEarthAdm1', countryCodes=NULL, al
     
     stateName <- locationsDF$stateName
     
-    # Sanity check -- missing stateCode implies location over water  
-    badMask <- is.na(stateName)
-    if (sum(badMask) > 0) {
-      if(is.null(countryCodes)) {
-        warning(paste(sum(badMask),"locations appear to be over international waters and no state can be assigned"))
-      } else {
-        warning(paste(sum(badMask),"locations appear to be either over international waters or not in given countryCodes and no state can be assigned"))
-      }
-    }  
-    
+
     return(stateName)
     
   }
