@@ -26,7 +26,10 @@ getVariable <- function(lon, lat, dataset=NULL, variable=NULL, countryCodes=NULL
   if ( is.null(dataset) || !exists(dataset) ) {
     stop('Missing database. Please loadSpatialData("',dataset,'")',call.=FALSE)
   }
-  
+  # check if longitude and latitude falls in the right range
+  if ( min(lon)< -180 || max(lon) > 180 || min(lat) < -90 || max(lat) > 90 ) {
+    stop('Longitude or latitude is not specified in the correct range -180:180, -90:90',call.=FALSE)
+  }  
   SPDF <- get(dataset)
   
   # Sanity check
